@@ -14,7 +14,7 @@ tool definition.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 The SCons Foundation
+# Copyright (c) 2001 - 2015 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -35,7 +35,7 @@ tool definition.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/__init__.py  2014/03/02 14:18:15 garyo"
+__revision__ = "src/engine/SCons/Tool/__init__.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
 
 import imp
 import sys
@@ -256,7 +256,7 @@ def VersionShLibLinkNames(version, libname, env):
         if Verbose:
             print "VersionShLibLinkNames: linkname = ",linkname
         linknames.append(linkname)
-    elif platform == 'posix':
+    elif platform == 'posix' or platform == 'sunos':
         if sys.platform.startswith('openbsd'):
             # OpenBSD uses x.y shared library versioning numbering convention
             # and doesn't use symlinks to backwards-compatible libraries
@@ -293,7 +293,7 @@ symlinks for the platform we are on"""
         version = None
 
     # libname includes the version number if one was given
-    libname = target[0].name
+    libname = getattr(target[0].attributes, 'shlibname', target[0].name)
     platform = env.subst('$PLATFORM')
     shlib_suffix = env.subst('$SHLIBSUFFIX')
     shlink_flags = SCons.Util.CLVar(env.subst('$SHLINKFLAGS'))
@@ -317,6 +317,11 @@ symlinks for the platform we are on"""
                 shlink_flags += [ '-Wl,-soname=%s' % soname ]
                 if Verbose:
                     print " soname ",soname,", shlink_flags ",shlink_flags
+        elif platform == 'sunos':
+            suffix_re = re.escape(shlib_suffix + '.' + version)
+            (major, age, revision) = version.split(".")
+            soname = re.sub(suffix_re, shlib_suffix, libname) + '.' + major
+            shlink_flags += [ '-h', soname ]
         elif platform == 'cygwin':
             shlink_flags += [ '-Wl,-Bsymbolic',
                               '-Wl,--out-implib,${TARGET.base}.a' ]
@@ -335,12 +340,16 @@ symlinks for the platform we are on"""
 
     if version:
         # here we need the full pathname so the links end up in the right directory
-        libname = target[0].path
+        libname = getattr(target[0].attributes, 'shlibpath', target[0].path)
+        if Verbose:
+            print "VerShLib: target lib is = ", libname
+            print "VerShLib: name is = ", target[0].name
+            print "VerShLib: dir is = ", target[0].dir.path
         linknames = VersionShLibLinkNames(version, libname, env)
         if Verbose:
             print "VerShLib: linknames ",linknames
         # Here we just need the file name w/o path as the target of the link
-        lib_ver = target[0].name
+        lib_ver = getattr(target[0].attributes, 'shlibname', target[0].name)
         # make symlink of adjacent names in linknames
         for count in range(len(linknames)):
             linkname = linknames[count]
@@ -705,7 +714,7 @@ def tool_list(platform, env):
         assemblers = ['masm', 'nasm', 'gas', '386asm' ]
         fortran_compilers = ['gfortran', 'g77', 'ifl', 'cvf', 'f95', 'f90', 'fortran']
         ars = ['mslib', 'ar', 'tlib']
-        other_plat_tools=['msvs','midl']
+        other_plat_tools = ['msvs', 'midl']
     elif str(platform) == 'os2':
         "prefer IBM tools on OS/2"
         linkers = ['ilink', 'gnulink', ]#'mslink']
@@ -772,6 +781,9 @@ def tool_list(platform, env):
         fortran_compilers = ['gfortran', 'g77', 'ifort', 'ifl', 'f95', 'f90', 'f77']
         ars = ['ar', 'mslib']
 
+    if not str(platform) == 'win32':
+        other_plat_tools += ['m4', 'rpm']
+
     c_compiler = FindTool(c_compilers, env) or c_compilers[0]
 
     # XXX this logic about what tool provides what should somehow be
@@ -795,12 +807,13 @@ def tool_list(platform, env):
         fortran_compiler = FindTool(fortran_compilers, env) or fortran_compilers[0]
         ar = FindTool(ars, env) or ars[0]
 
+    d_compilers = ['dmd', 'gdc', 'ldc']
+    d_compiler = FindTool(d_compilers, env) or d_compilers[0]
+
     other_tools = FindAllTools(other_plat_tools + [
-                               'dmd',
                                #TODO: merge 'install' into 'filesystem' and
                                # make 'filesystem' the default
                                'filesystem',
-                               'm4',
                                'wix', #'midl', 'msvs',
                                # Parser generators
                                'lex', 'yacc',
@@ -812,14 +825,14 @@ def tool_list(platform, env):
                                'dvipdf', 'dvips', 'gs',
                                'tex', 'latex', 'pdflatex', 'pdftex',
                                # Archivers
-                               'tar', 'zip', 'rpm',
+                               'tar', 'zip',
                                # SourceCode factories
                                'BitKeeper', 'CVS', 'Perforce',
                                'RCS', 'SCCS', # 'Subversion',
                                ], env)
 
     tools = ([linker, c_compiler, cxx_compiler,
-              fortran_compiler, assembler, ar]
+              fortran_compiler, assembler, ar, d_compiler]
              + other_tools)
 
     return [x for x in tools if x]
