@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2014 The SCons Foundation
+# Copyright (c) 2001 - 2015 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/jar.py  2014/08/24 12:12:31 garyo"
+__revision__ = "src/engine/SCons/Tool/jar.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
 
 import SCons.Subst
 import SCons.Util
@@ -97,7 +97,7 @@ def generate(env):
     env['_JARMANIFEST'] = jarManifest
     env['_JARSOURCES'] = jarSources
     env['_JARCOM']    = '$JAR $_JARFLAGS $TARGET $_JARMANIFEST $_JARSOURCES'
-    env['JARCOM']     = "${TEMPFILE('$_JARCOM')}"
+    env['JARCOM']     = "${TEMPFILE('$_JARCOM','$JARCOMSTR')}"
     env['JARSUFFIX']  = '.jar'
 
 def exists(env):
