@@ -5,7 +5,7 @@ The main package for the SCons software construction utility.
 """
 
 #
-# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 The SCons Foundation
+# Copyright (c) 2001 - 2015 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,14 +27,23 @@ The main package for the SCons software construction utility.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/__init__.py 3266 2008/08/12 07:31:01 knight"
+__revision__ = "src/engine/SCons/__init__.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
 
-__version__ = "1.0.0"
+__version__ = "2.3.6"
 
-__build__ = "r3266"
+__build__ = "rel_2.3.5:3347:d31d5a4e74b6[MODIFIED]"
 
-__buildsys__ = "bangkok"
+__buildsys__ = "hpmicrodog"
 
-__date__ = "2008/08/12 07:31:01"
+__date__ = "2015/07/31 14:36:10"
 
-__developer__ = "knight"
+__developer__ = "bdbaddog"
+
+# make sure compatibility is always in place
+import SCons.compat
+
+# Local Variables:
+# tab-width:4
+# indent-tabs-mode:nil
+# End:
+# vim: set expandtab tabstop=4 shiftwidth=4:
